import time
from rich import print

from pmodoro.progress import MyProgress


class Pmodoro:
    def __init__(self):
        self.progress = MyProgress()

    def timer(self, duration_in_sec: float, message: str, message_finished: str):
        print(f"⏳ Started at: {time.ctime()}")
        msg = message or "Concentrating..."
        finished_msg = message_finished or "🥳 Done!"
        self.progress.start()
        for value in self.progress.track(
            range(round(duration_in_sec), 0, -1), description=msg
        ):
            time.sleep(1)
        self.progress.stop()
        print(finished_msg)



import unittest
from typer.testing import CliRunner

from pmodoro import __app_name__, __version__, cli

runner = CliRunner()


class TestCliMethods(unittest.TestCase):
    def test_version(self):
        result = runner.invoke(cli.app, ["--version"])
        self.assertEqual(result.exit_code, 0)
        self.assertEqual(f"{__app_name__} version {__version__}\n", result.stdout)

    def test_timer_setup(self):
        # Test that the timer is set up correctly with a given duration
        duration = 0.0001
        result = runner.invoke(cli.app, ["start", str(duration)])
        self.assertEqual(result.exit_code, 0)
        self.assertIn(f"⏳ Started at:", result.stdout)

    def test_timer_msg(self):
        duration = 0.0001
        result = runner.invoke(
            cli.app, ["start", str(duration), "--msg=Custom message"]
        )
        self.assertEqual(result.exit_code, 0)
        self.assertIn(f"Custom message", result.stdout)

    def test_timer_msg_done(self):
        duration = 0.0001
        result = runner.invoke(
            cli.app, ["start", str(duration), "--msg-done=custom done!"]
        )
        self.assertEqual(result.exit_code, 0)
        self.assertIn(f"custom done!", result.stdout)

    def test_timer_msg_and_msg_done(self):
        duration = 0.0001
        result = runner.invoke(
            cli.app,
            ["start", str(duration), "--msg=Custom message", "--msg-done=custom done!"],
        )
        self.assertEqual(result.exit_code, 0)
        self.assertIn(f"Custom message", result.stdout)
        self.assertIn(f"custom done!", result.stdout)



import datetime
from rich.panel import Panel
from rich.progress import Progress
from rich.table import Table


class MyProgress(Progress):
    pass
    # def get_renderables(self):
    #     yield Panel(self.make_tasks_table(self.tasks))



from typing import Optional
from typing_extensions import Annotated
import typer
from rich import print

from pmodoro import __version__, __app_name__
from pmodoro.pmdoro import Pmodoro


app = typer.Typer()


def _version_callback(value: bool):
    if value:
        typer.echo(f"{__app_name__} version {__version__}")
        raise typer.Exit()


@app.callback()
def main(
    version: Optional[bool] = typer.Option(
        None,
        "--version",
        "-v",
        callback=_version_callback,
        is_eager=True,
        help="Show the version and exit.",
    ),
) -> None:
    """
    Pomodoro CLI - A command-line interface for managing pomodoro tasks.

    This tool helps you manage your pomodoro sessions and tasks efficiently.
    """


@app.command()
def start(
    duration_in_mins: Annotated[
        float,
        typer.Argument(
            help="Start timer by giving duration in mins",
        ),
    ] = 25,
    msg: Annotated[
        str, typer.Option(help="The message to show when concentrating.")
    ] = "",
    msg_done: Annotated[
        str, typer.Option(help="Message to show when session is done.")
    ] = "",
) -> None:
    duration_in_secs = duration_in_mins * 60
    runner = Pmodoro()
    runner.timer(duration_in_secs, msg, msg_done)
